@@ -482,6 +482,9 @@ def continuation_line_indentation(logical_line, tokens, indent_level, verbose):
         print(">>> " + tokens[0][4].rstrip())
 
     for token_type, text, start, end, line in tokens:
+        if line.strip().lower().endswith('# nopep8'):
+            continue
+
         newline = row < start[0] - first_row
         if newline:
             row = start[0] - first_row
@@ -1882,7 +1885,7 @@ def process_options(arglist=None, parse_argv=False, config_file=None):
                       help="use exit code 0 (success), even if there are "
                         "warnings")
     parser.add_option('--max-complexity', default=-1, action='store',
-                      type='int', help="McCabe complexity treshold")
+                      type='int', help="McCabe complexity threshold")
 
     options, args = parser.parse_args(arglist)
     options.reporter = None
