@@ -3,8 +3,10 @@ import re
 import os
 
 
-def skip_warning(warning):
+def skip_warning(warning, ignore=[]):
     # XXX quick dirty hack, just need to keep the line in the warning
+    if warning.message.split()[0] in ignore:
+        return True
     if not os.path.isfile(warning.filename):
         return False
 
@@ -27,6 +29,8 @@ def skip_file(path):
 
     # flake8: noqa
     """
+    if not os.path.isfile(path):
+        return False
     f = open(path)
     try:
         content = f.read()
